*******
History
*******

Release 0.1 (2018-01-17)
========================

No code changes.

This package is now deemed "production ready" (though your mileage may vary.)

Release 0.1b1 (2018-01-09)
==========================

Initial release.
